@@ -29,6 +29,8 @@ GtkWidget *config_search_plugin_combo;
 GtkWidget *hvsc_path_selection_button;
 GtkWidget *hvsc_path_label;
 
+GtkWidget *output_mode_toggle;
+
 //
 // TODO - make this all more generic and error-proof
 //
@@ -72,7 +74,9 @@ GtkWidget* create_config_page (void)
     *s_plugin_box,
     *hvsc_box,
 
+    *output_label,
     *label,
+    *sep2,
     *sep,
 
     *plugin_label;
@@ -96,18 +100,24 @@ GtkWidget* create_config_page (void)
   hvsc_box = gtk_hbox_new (FALSE, 0);
 
   label = gtk_label_new ("Local HVSC path");
+  output_label = gtk_label_new ("Output mode");
+  output_mode_toggle = gtk_toggle_button_new_with_label ("Stereo output");
   hvsc_path_selection_button  = create_ui_button ("not supported yet");
 
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(output_mode_toggle), TRUE);
+
   gtk_widget_set_sensitive (hvsc_path_selection_button, FALSE);
 
   plugin_label = gtk_label_new ("Choose plugins");
   hvsc_path_label = gtk_label_new ("");
 
   gtk_label_set_markup (GTK_LABEL (label), "<b>Local HVSC path</b>");
+  gtk_label_set_markup (GTK_LABEL (output_label), "<b>Output mode</b>");
   gtk_label_set_markup (GTK_LABEL (plugin_label), "<b>Choose plugins</b>");
   gtk_label_set_markup (GTK_LABEL (hvsc_path_label), "<i>unspecified</i>");
 
   sep = gtk_hseparator_new();
+  sep2 = gtk_hseparator_new();
 
   snprintf(buffer, 256, "%s/audio", PLUGIN_FILE_PATH);
   config_audio_plugin_combo  = create_plugin_chooser ("audio", buffer);
@@ -124,15 +134,20 @@ GtkWidget* create_config_page (void)
   gtk_box_pack_start (GTK_BOX(s_plugin_box), config_search_plugin_combo,  TRUE,  TRUE,  2);
   gtk_box_pack_start (GTK_BOX(s_plugin_box), config_search_plugin_button, FALSE, FALSE, 2);
 
-  gtk_box_pack_start (GTK_BOX(config_main_box), label, FALSE, FALSE, 0);
 
-  gtk_box_pack_start (GTK_BOX(hvsc_box), hvsc_path_selection_button, TRUE, TRUE, 0);
+  /*
+    TODO - add local HVSC support!
+    gtk_box_pack_start (GTK_BOX(config_main_box), label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX(hvsc_box), hvsc_path_selection_button, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX(config_main_box), hvsc_box, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX(config_main_box), hvsc_path_label, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX(config_main_box), sep, FALSE, FALSE, 0);
+  */
 
-  gtk_box_pack_start (GTK_BOX(config_main_box), hvsc_box, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(config_main_box), output_label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(config_main_box), output_mode_toggle, FALSE, FALSE, 0);
 
-  gtk_box_pack_start (GTK_BOX(config_main_box), hvsc_path_label, FALSE, FALSE, 0);
-
-  gtk_box_pack_start (GTK_BOX(config_main_box), sep, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX(config_main_box), sep2, FALSE, FALSE, 0);
 
   gtk_box_pack_start (GTK_BOX(config_main_box), plugin_label, FALSE, FALSE, 0);
 
